#include <stdio.h>
#include <string.h>

const int MAXVAL = 13;

enum HandType {
    tNothing = 0,
    tPair,
    t2Pair,
    tThree,
    tStraight,
    tFlush,
    tFull,
    tPoker,
    tStraightFlush,
};

struct Card {
    int value;
    char suit;
};

struct Group {
    int value, size;
};

template<class T>
void swap(T& x, T&y) { T t = x; x = y; y = t; }

int CheckHand(Card hand[])
{
    int i, j;
    int pts;
    HandType type;

    // order cards
    for ( i = 1; i < 5; i++ )
        for ( j = i; j > 0 && hand[j - 1].value > hand[j].value; j-- )
            swap(hand[j - 1], hand[j]);

    // straight or flush
    bool flush = true;
    bool straight = true;
    for ( i = 1; i < 5; i++ ) {
        flush = flush && (hand[i].suit == hand[0].suit);
        straight = straight && (hand[i].value - hand[0].value == i);
    }

    // groups of same value
    Group group[2];
    int ng = 0;
    for ( i = 1; i < 5; i++ )
        if ( hand[i].value == hand[i - 1].value ) {
            if ( ng == 0 || group[ng - 1].value != hand[i].value ) {
                ++ng;
                group[ng - 1].value = hand[i].value;
                group[ng - 1].size = 2;
            } else {
                ++group[ng - 1].size;
            }
        }

    if ( ng == 1 ) {
        // pair, threes, poker
        switch ( group[0].size ) {
            case 2: type = tPair; break;
            case 3: type = tThree; break;
            case 4: type = tPoker; break;
        }
        pts = group[0].value;
    }
    else if ( ng == 2 ) {
        if ( group[0].size > group[1].size )
            swap(group[0], group[1]);
        // two pairs or full house
        if ( group[1].size == 3 ) {
            type = tFull;
            pts = group[1].value;
        } else {
            type = t2Pair;
            pts = group[1].value * MAXVAL + group[0].value;
        }
    }
    else if ( straight ) {
        // straight (flush)
        if ( flush ) type = tStraightFlush;
            else type = tStraight;
        pts = hand[4].value;
    }
    else {
        // flush or nothing
        if ( flush ) type = tFlush;
            else type = tNothing;
        // high card points
        pts = 0;
        for ( i = 4; i >= 0; i-- )
            pts = 13 * pts + hand[i].value;
    }

    return type * 1000000 + pts;
}

int main()
{
    static char values[] = "23456789TJQKA";
    char hs[40];
    Card cards[10];

    while ( gets(hs) ) {
        if ( strlen(hs) < 29 ) break;

        for ( int i = 0; i < 10; i++ ) {
            cards[i].value = strchr(values, hs[3 * i]) - values;
            cards[i].suit = hs[3 * i + 1];
        }

        int v1 = CheckHand(cards);
        int v2 = CheckHand(cards + 5);

        if ( v1 < v2 ) printf("White wins.\n");
        else if ( v1 > v2 ) printf("Black wins.\n");
        else printf("Tie.\n");
    }

    return 0;
}

